package com.muyu.authentication.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.authentication.domain.req.AuthenticationQueryReq;
import com.muyu.authentication.domain.req.AuthenticationSaveReq;
import com.muyu.authentication.domain.req.AuthenticationEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 认证对象 authentication
 *
 * @author wan
 * @date 2024-05-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("authentication")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Authentication", description = "认证")
public class Authentication extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 企业认证主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "企业认证主键", value = "企业认证主键")
    private Long id;

    /** 审核报告人 */
    @Excel(name = "审核报告人")
    @ApiModelProperty(name = "审核报告人", value = "审核报告人")
    private String auditor;

    /** 待审核,已通过,未通过 */
    @Excel(name = "待审核,已通过,未通过")
    @ApiModelProperty(name = "待审核,已通过,未通过", value = "待审核,已通过,未通过")
    private String stat;

    /** 审核报告 */
    @Excel(name = "审核报告")
    @ApiModelProperty(name = "审核报告", value = "审核报告")
    private String auditReason;

    /**
    * 查询构造器
    */
    public static Authentication queryBuild( AuthenticationQueryReq authenticationQueryReq){
        return Authentication.builder()
                .auditor(authenticationQueryReq.getAuditor())
                .stat(authenticationQueryReq.getStat())
                .auditReason(authenticationQueryReq.getAuditReason())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Authentication saveBuild(AuthenticationSaveReq authenticationSaveReq){
        return Authentication.builder()
                .auditor(authenticationSaveReq.getAuditor())
                .stat(authenticationSaveReq.getStat())
                .auditReason(authenticationSaveReq.getAuditReason())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Authentication editBuild(Long id, AuthenticationEditReq authenticationEditReq){
        return Authentication.builder()
            .id(id)
                .auditor(authenticationEditReq.getAuditor())
                .stat(authenticationEditReq.getStat())
                .auditReason(authenticationEditReq.getAuditReason())
                .build();
    }

}
