package com.muyu.company.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.company.domain.req.CompanyQueryReq;
import com.muyu.company.domain.req.CompanySaveReq;
import com.muyu.company.domain.req.CompanyEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 企业对象 company
 *
 * @author wan
 * @date 2024-05-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("company")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Company", description = "企业")
public class Company extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 企业名称 */
    @Excel(name = "企业名称")
    @ApiModelProperty(name = "企业名称", value = "企业名称")
    private String companyName;

    /** 法定代理人 */
    @Excel(name = "法定代理人")
    @ApiModelProperty(name = "法定代理人", value = "法定代理人")
    private String legalRepresentative;

    /** 企业注册时获得的合法经营凭证号码 */
    @Excel(name = "企业注册时获得的合法经营凭证号码")
    @ApiModelProperty(name = "企业注册时获得的合法经营凭证号码", value = "企业注册时获得的合法经营凭证号码")
    private String businessLicenseNumber;

    /** 企业成立的日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "企业成立的日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "企业成立的日期", value = "企业成立的日期")
    private Date companyTime;

    /** 经营范围 */
    @Excel(name = "经营范围")
    @ApiModelProperty(name = "经营范围", value = "经营范围")
    private String sphereOfBusiness;

    /** 注册地址 */
    @Excel(name = "注册地址")
    @ApiModelProperty(name = "注册地址", value = "注册地址")
    private String registeredAddress;

    /** 负责人电话 */
    @Excel(name = "负责人电话")
    @ApiModelProperty(name = "负责人电话", value = "负责人电话")
    private String companyPhone;

    /** 负责人邮箱 */
    @Excel(name = "负责人邮箱")
    @ApiModelProperty(name = "负责人邮箱", value = "负责人邮箱")
    private String companyMailbox;

    /** 企业当前的状态,如正常状态,暂停,注销 */
    @Excel(name = "企业当前的状态,如正常状态,暂停,注销")
    @ApiModelProperty(name = "企业当前的状态,如正常状态,暂停,注销", value = "企业当前的状态,如正常状态,暂停,注销")
    private String companyStatus;

    /** 企业入驻时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "企业入驻时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "企业入驻时间", value = "企业入驻时间")
    private Date enterTime;

    /** 企业认证主键 */
    @Excel(name = "企业认证主键")
    @ApiModelProperty(name = "企业认证主键", value = "企业认证主键")
    private Long authenticationId;

    /** 开通服务主键 */
    @Excel(name = "开通服务主键")
    @ApiModelProperty(name = "开通服务主键", value = "开通服务主键")
    private Long liberalServiceId;

    /** 增值服务主键 */
    @Excel(name = "增值服务主键")
    @ApiModelProperty(name = "增值服务主键", value = "增值服务主键")
    private Long appreciationServiceId;

    /** 用户ID */
    @Excel(name = "用户ID")
    @ApiModelProperty(name = "用户ID", value = "用户ID")
    private Long userId;

    /**
    * 查询构造器
    */
    public static Company queryBuild( CompanyQueryReq companyQueryReq){
        return Company.builder()
                .companyName(companyQueryReq.getCompanyName())
                .legalRepresentative(companyQueryReq.getLegalRepresentative())
                .businessLicenseNumber(companyQueryReq.getBusinessLicenseNumber())
                .companyTime(companyQueryReq.getCompanyTime())
                .sphereOfBusiness(companyQueryReq.getSphereOfBusiness())
                .registeredAddress(companyQueryReq.getRegisteredAddress())
                .companyPhone(companyQueryReq.getCompanyPhone())
                .companyMailbox(companyQueryReq.getCompanyMailbox())
                .companyStatus(companyQueryReq.getCompanyStatus())
                .enterTime(companyQueryReq.getEnterTime())
                .authenticationId(companyQueryReq.getAuthenticationId())
                .liberalServiceId(companyQueryReq.getLiberalServiceId())
                .appreciationServiceId(companyQueryReq.getAppreciationServiceId())
                .userId(companyQueryReq.getUserId())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Company saveBuild(CompanySaveReq companySaveReq){
        return Company.builder()
                .companyName(companySaveReq.getCompanyName())
                .legalRepresentative(companySaveReq.getLegalRepresentative())
                .businessLicenseNumber(companySaveReq.getBusinessLicenseNumber())
                .companyTime(companySaveReq.getCompanyTime())
                .sphereOfBusiness(companySaveReq.getSphereOfBusiness())
                .registeredAddress(companySaveReq.getRegisteredAddress())
                .companyPhone(companySaveReq.getCompanyPhone())
                .companyMailbox(companySaveReq.getCompanyMailbox())
                .companyStatus(companySaveReq.getCompanyStatus())
                .enterTime(companySaveReq.getEnterTime())
                .authenticationId(companySaveReq.getAuthenticationId())
                .liberalServiceId(companySaveReq.getLiberalServiceId())
                .appreciationServiceId(companySaveReq.getAppreciationServiceId())
                .userId(companySaveReq.getUserId())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Company editBuild(Long id, CompanyEditReq companyEditReq){
        return Company.builder()
            .id(id)
                .companyName(companyEditReq.getCompanyName())
                .legalRepresentative(companyEditReq.getLegalRepresentative())
                .businessLicenseNumber(companyEditReq.getBusinessLicenseNumber())
                .companyTime(companyEditReq.getCompanyTime())
                .sphereOfBusiness(companyEditReq.getSphereOfBusiness())
                .registeredAddress(companyEditReq.getRegisteredAddress())
                .companyPhone(companyEditReq.getCompanyPhone())
                .companyMailbox(companyEditReq.getCompanyMailbox())
                .companyStatus(companyEditReq.getCompanyStatus())
                .enterTime(companyEditReq.getEnterTime())
                .authenticationId(companyEditReq.getAuthenticationId())
                .liberalServiceId(companyEditReq.getLiberalServiceId())
                .appreciationServiceId(companyEditReq.getAppreciationServiceId())
                .userId(companyEditReq.getUserId())
                .build();
    }

}
