package com.muyu.pay.domain;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.pay.domain.req.PayQueryReq;
import com.muyu.pay.domain.req.PaySaveReq;
import com.muyu.pay.domain.req.PayEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 支付对象 pay
 *
 * @author wan
 * @date 2024-05-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("pay")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Pay", description = "支付")
public class Pay extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 支付主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "支付主键", value = "支付主键")
    private Long id;

    /** 企业主键 */
    @Excel(name = "企业主键")
    @ApiModelProperty(name = "企业主键", value = "企业主键")
    private Long companyId;

    /** 支付方式主键 */
    @Excel(name = "支付方式主键")
    @ApiModelProperty(name = "支付方式主键", value = "支付方式主键")
    private Long paymentId;

    /** 增值需要支付的价格 */
    @Excel(name = "增值需要支付的价格")
    @ApiModelProperty(name = "增值需要支付的价格", value = "增值需要支付的价格")
    private BigDecimal appreciationDecimal;

    /**
    * 查询构造器
    */
    public static Pay queryBuild( PayQueryReq payQueryReq){
        return Pay.builder()
                .companyId(payQueryReq.getCompanyId())
                .paymentId(payQueryReq.getPaymentId())
                .appreciationDecimal(payQueryReq.getAppreciationDecimal())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Pay saveBuild(PaySaveReq paySaveReq){
        return Pay.builder()
                .companyId(paySaveReq.getCompanyId())
                .paymentId(paySaveReq.getPaymentId())
                .appreciationDecimal(paySaveReq.getAppreciationDecimal())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Pay editBuild(Long id, PayEditReq payEditReq){
        return Pay.builder()
            .id(id)
                .companyId(payEditReq.getCompanyId())
                .paymentId(payEditReq.getPaymentId())
                .appreciationDecimal(payEditReq.getAppreciationDecimal())
                .build();
    }

}
